local st = "$S_TIME"

* PRODUCING OUTPUT TABLES FROM MULTIPLE REGRESSIONS FOR LATEX
* Stata 11, Windows
* Miguel Portela
* September 2010

clear all
set mem 1m
set more off
set rmsg on

cd "C:\miguel\My Dropbox\_stata"

capture log close
log using output.log, text replace

* GENERATE THE SAMPLE
set obs 1000
	gen x1 = uniform()
	gen x2 = sqrt(uniform()*10)
	gen x3 = rchi2(12)
	gen x4 = rgamma(3,15)
	gen x5 = rpoisson(17)
	gen x6 = rt(7)

	label var x1 "Uniform"
	label var x2 "Sqrt, Uniform"
	label var x3 "Chi-2"
	label var x4 "Gamma"
	label var x5 "Poisson"
	label var x6 "t-student"
	
	gen y = 7*x1 + 11*x2 + x3 + uniform()

* ESTIMATIONS

xi: reg y x1
	est store R1
	est2vec table_regs, vars(x1 x2 x3 x4 x5 x6) e(N r2 r2_a ll rmse) name(R1)
	
	test x1
		mat p = r(F)\r(df)\r(p)

xi: reg y x1 x2
	est store R2
	est2vec table_regs, addto(table_regs) name (R2)

	test x1 x2
		mat p = p,(r(F)\r(df)\r(p))

xi: reg y x1 x2 x3
	est store R3
	est2vec table_regs, addto(table_regs) name (R3)

	test x1 x2 x3
		mat p = p,(r(F)\r(df)\r(p))

xi: reg y x1 x2 x3 x4
	est store R4
	est2vec table_regs, addto(table_regs) name (R4)

	test x1 x2 x3 x4
		mat p = p,(r(F)\r(df)\r(p))

xi: reg y x1 x2 x3 x4 x5
	est store R5
	est2vec table_regs, addto(table_regs) name (R5)

	test x1 x2 x3 x4 x5
		mat p = p,(r(F)\r(df)\r(p))

xi: reg y x1 x2 x3 x4 x5 x6
	est store R6
	est2vec table_regs, addto(table_regs) name (R6)

	test x1 x2 x3 x4 x5 x6
		mat p = p,(r(F)\r(df)\r(p))

mat l p

*** ADD THE OVERALL SIGNIFICANCE TEST TO THE OUTPUT SENT TO LATEX
mat table_regs_e=p\table_regs_e

est table R1 R2 R3 R4 R6 R6, star( .1 .05 .01) b(%9.3f) keep(x1 x2 x3 x4 x5 x6) title(Table 1: OLS results, random numbers, Short stars)
est table R1 R2 R3 R4 R6 R6, keep(x1 x2 x3 x4 x5 x6) b(%7.3f) se(%7.3f) p(%7.3f) stfmt(%7.3g) title(Table 2: OLS results, random numbers, Full) newpanel label stats(N r2_a aic bic rank rmse)

	est2tex table_regs, preserve replace dropall path(C:\miguel\My Dropbox\_stata) mark(starb) levels(90 95 99) fancy label digits(3)
		sh copy "C:\miguel\My Dropbox\_stata\table_regs.tex" "C:\miguel\My Dropbox\_stata\table_regs2.tex"

elapse `st'

log close

